"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateComponentsFromOpenapi = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const handlers_generator_1 = require("../handlers-generator/handlers-generator");
const openapi_parser_1 = require("../openapi-parser/openapi-parser");
const openapi_reader_1 = require("../openapi-reader/openapi-reader");
const openapi_version_verifier_1 = require("../openapi-version-verifier/openapi-version-verifier");
const routes_schemas_generator_1 = require("../routes-schemas-generator/routes-schemas-generator");
const schemas_generator_1 = require("../schemas-generator/schemas-generator");
const openapi_generator_consts_1 = require("./openapi-generator.consts");
async function generateComponentsFromOpenapi({ rootDir, openapiFileRelativePath, destinationFolderRelativePath, }) {
    const basFolder = path_1.default.join(rootDir, destinationFolderRelativePath);
    const openapiPath = path_1.default.join(rootDir, openapiFileRelativePath);
    const reader = new openapi_reader_1.OpenapiReader();
    const parser = new openapi_parser_1.OpenapiParser();
    const versionVerifier = new openapi_version_verifier_1.OpenApiVersionVerifier();
    const routesSchemasGenerator = new routes_schemas_generator_1.RoutesSchemasGenerator(reader, parser, versionVerifier, openapiPath);
    const openapiWithRoutesSchemas = routesSchemasGenerator.generateRoutesSchemas();
    await new schemas_generator_1.SchemasGenerator(openapiWithRoutesSchemas, basFolder).generateSchemas();
    const handlersGenerator = new handlers_generator_1.HandlersGenerator(reader, parser, openapiPath);
    const handlersPath = path_1.default.join(basFolder, openapi_generator_consts_1.handlersFileName);
    const handlers = handlersGenerator.generateHandlers();
    fs_1.default.writeFileSync(handlersPath, handlers);
}
exports.generateComponentsFromOpenapi = generateComponentsFromOpenapi;
