"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoutesSchemasGenerator = void 0;
const openapi_manager_v3_1_service_1 = require("../openapi-manger/v3_1/openapi-manager-v3_1.service");
const openapi_version_verifier_models_1 = require("../openapi-version-verifier/openapi-version-verifier.models");
const openapi_manager_v3_0_service_1 = require("../openapi-manger/v3_0/openapi-manager-v3_0.service");
class RoutesSchemasGenerator {
    constructor(openapiReader, openapiParser, openapiVersionVerifier, openapiFilePath) {
        this.openapiReader = openapiReader;
        this.openapiParser = openapiParser;
        this.openapiVersionVerifier = openapiVersionVerifier;
        this.openapiFilePath = openapiFilePath;
    }
    generateRoutesSchemas() {
        const openapiRaw = this.openapiReader.readOpenapi(this.openapiFilePath);
        const openapi = this.openapiParser.parseOpeanpi(openapiRaw);
        const manager = this.getOpenapiManager(openapi);
        return manager.generateOpenapiWithRoutesSchemas(openapi);
    }
    getOpenapiManager(openapi) {
        const version = this.openapiVersionVerifier.getOpenApiVersion(openapi);
        switch (version) {
            case openapi_version_verifier_models_1.OpenApiVersion.V3_1:
                return new openapi_manager_v3_1_service_1.OpenApiManagerV3_1();
            case openapi_version_verifier_models_1.OpenApiVersion.V3_0:
                return new openapi_manager_v3_0_service_1.OpenApiManagerV3_0();
        }
    }
}
exports.RoutesSchemasGenerator = RoutesSchemasGenerator;
